pub(crate) struct PlaceholderMatch {
pub(crate) range: FileRange,
pub(crate) inner_matches: SsrMatches,
pub(crate) autoderef_count: usize,
pub(crate) autoref_kind: SelfParamKind,
}Expand description
Information about a placeholder bound in a match.
Fields
range: FileRangeinner_matches: SsrMatchesMore matches, found within node.
autoderef_count: usizeHow many times the code that the placeholder matched needed to be dereferenced. Will only be non-zero if the placeholder matched to the receiver of a method call.
autoref_kind: SelfParamKindImplementations
Sourceimpl PlaceholderMatch
impl PlaceholderMatch
fn from_range(range: FileRange) -> Self