enum Phase<'a> {
First,
Second(&'a mut Match),
}Expand description
Which phase of matching we’re currently performing. We do two phases because most attempted matches will fail and it means we can defer more expensive checks to the second phase.
Variants
First
On the first phase, we perform cheap checks. No state is mutated and nothing is recorded.
Second(&'a mut Match)
On the second phase, we construct the Match. Things like what placeholders bind to is
recorded.
Implementations
Sourceimpl Phase<'_>
impl Phase<'_>
fn next_non_trivial( &mut self, code_it: &mut SyntaxElementChildren, ) -> Option<SyntaxElement>
fn record_ignored_comments(&mut self, token: &SyntaxToken)